import 'package:codenic_exception_converter/src/exception_conversions/base_exception_conversion.dart';
import 'package:codenic_exception_converter/src/failures/failure.dart';
import 'package:codenic_logger/codenic_logger.dart';

/// {@template DefaultExceptionConversion}
/// If [Exception] occurs, then [Failure] is returned.
///
/// If no error occurs, then value [T] is returned.
/// {@endtemplate}
class DefaultExceptionConversion<T>
    extends BaseExceptionConversion<T, Exception, Failure> {
  /// {@macro DefaultExceptionConversion}
  const DefaultExceptionConversion();

  @override
  Failure onException({
    required Exception exception,
    StackTrace? stackTrace,
    CodenicLogger? logger,
    MessageLog? messageLog,
  }) {
    if (logger != null && messageLog != null) {
      logger.error(
        messageLog..message = 'Unknown failure occurred',
        error: exception,
        stackTrace: stackTrace,
      );
    }

    return const Failure();
  }
}
