import 'dart:io';

import 'package:codenic_exception_converter/codenic_exception_converter.dart';
import 'package:codenic_exception_converter/src/failures/network_failure.dart';
import 'package:codenic_logger/codenic_logger.dart';

/// {@template SocketExceptionConversion}
/// If [SocketException] occurs, then [NetworkFailure] is returned.
///
/// If no error occurs, then value [T] is returned.
/// {@endtemplate}
class SocketExceptionConversion<T>
    extends BaseExceptionConversion<T, SocketException, NetworkFailure> {
  /// {@macro SocketExceptionConversion}
  const SocketExceptionConversion();

  @override
  NetworkFailure onException({
    required SocketException exception,
    StackTrace? stackTrace,
    CodenicLogger? logger,
    MessageLog? messageLog,
  }) {
    if (logger != null && messageLog != null) {
      logger.warn(
        messageLog..message = 'Network failure occurred',
        error: exception,
        stackTrace: stackTrace,
      );
    }

    return const NetworkFailure();
  }
}
